function transformed_signal = ApplyWindow(input_signal,window)
% APPLYWINDOW applies a user-selected window function to a signal.
% 
% transformed_signal = ApplyWindow(input_signal,window) applies a
% user-selected window function, 'window', from the Signal Processing
% Toolbox, to 'input_signal' and returns it as , 'transformed_signal'.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Initialising a saving matrix for the outputted signal
transformed_signal = zeros(size(input_signal));

% Check that a window function has been selected
if (strcmp(window,'none')==0)
    
    % Determining properties of the signal
    signal_size = size(input_signal);
    
    % Determining the signal length
    signal_length = max(signal_size);
    max_dim = find(signal_size==signal_length);

    % Loop (applies only for matricies)
    for jj = 1:min(signal_size)
    
        % Determining the matrix alignment
        if (max_dim==1)
            
            % Applying a user-defined window to the signal
            transformed_signal(:,jj) = input_signal(:,jj).*eval([window,...
                '(',num2str(length(input_signal)),')']);
        
        % If the matrix alignment is different (occurs for phase coherence
        % analysis)
        elseif (max_dim==2)
            
            % Applying a user-defined window to the signal along the
            % correct dimensions
            transformed_signal(jj,:) = input_signal(jj,:).*eval([window,...
                '(',num2str(length(input_signal)),')''']);
            
        end
    end
else
    
    % Setting the outputted signal to the input signal if no window has
    % been applied
    transformed_signal = input_signal;
    
end