function Band_Decomposition_Plot(segment_time,decomp_bands,...
    segment_band_ratios)
% BAND_DECOMPOSITION_PLOT generates figures of the spectrally decomposed
% signals.
% 
% Band_Decomposition_Plot(segment_time,decomp_bands,segment_band_ratios)
% generates several subplots containing information about the signal 
% ('decomp_bands'). The first subplot is the original signal, and the rest 
% are the spectrally decomposed signals according to the set bands. The 
% first plot is labelled according to its time segment ('t1' and 't2') of 
% the original signal, and all remaining plots are labelled according to 
% their band using their names ('band_names'). These subplots also contain
% data about their percentage power in the legend.
% 
% See also BAND_DECOMPOSITION.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global t1 t2 band_names

% Formining enough subplots
num_subplots = length(band_names)+1;
dim_x = floor(sqrt(num_subplots));
dim_y = ceil(num_subplots/dim_x);

% Plot the original signal
figure('NumberTitle','off','Name','Separate Signal into Frequency Bands')
subplot(dim_y,dim_x,1)
plot(segment_time,decomp_bands(1,:))
grid on
xlabel('Time /s')
ylabel('Voltage /mV')
title(sprintf('Total Signal (%.0f - %.0fs)',t1,t2))

%Plot each band graph
for jj = 2:num_subplots
    
    % Plot each band as a subplot
    subplot(dim_y,dim_x,jj)
    plot(segment_time,decomp_bands(jj,:))
    grid on
    xlabel('Time /s')
    ylabel('Voltage /mV')
    title(sprintf('%s (%.2f%% of Total Power)',band_names{jj-1},...
        100*segment_band_ratios(jj-1)))
    
end