function [transformed_signal,frequency_scale] = Fourier(input_signal)
% FOURIER Frequency-domain signal via Fourier transform.
% 
% transformed_signal = Fourier(input_signal) computes the shifted Fourier
% transform of an input signal.
% 
% [transformed_signal,frequency_scale] = Fourier(input_signal) returns both
% the transformed signal as well as the correct frequency scale for the
% signal.
% 
% The function uses the global variables 'fourier_window' and
% 'sample_rate'; the former determines whether or not the user wishes a
% window (derived from other inbuilt Matlab windowing functions) to be
% applied to the signal, although this can be left blank. The latter is 
% the sample rate of the signal which is used to determine the frequency 
% scale.
% 
% See also FFT, FFTSHIFT, ISOLATE_BAND.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading the required global variables
global sample_rate

% Obtaining the frequency spectrum of the original signal
transformed_signal = fftshift(fft(input_signal));

% Calculate the frequency domain
frequency_scale = linspace(-(sample_rate)/2,(sample_rate)/2,...
    length(transformed_signal));