function GUI_AlternateSegment(varargin)
% GUI_ALTERNATESEGMENT is the programmed GUI for selecting other segments 
% from a reference channel signal that appears in the program 
% 'LFP Analysis Software 2009'.
% 
% GUI_AlternateSegment(varargin) allows the user to select other segments
% of the same length as the reference segment from the reference channel
% signal for further analysis (usually in Multi-Channel Analysis). This can
% either be done manually, or by using Sequential Segmentation.
% 
% See also GUI_SEQUENTIALSEGMENTATION, TIME_SEQUENCE.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading the required global variables
global reference_channel channel_time VoltageScale VoltageValue sample_rate
global sequence_counter segment_length

% Creating the figure window for alternate segments
DSFigure = figure('Units','characters','MenuBar','none','Name',...
    'Save Segments to Workspace','NumberTitle','off','Position',...
    [90 5 110 50],'ReSize','off','Visible','off');

% Adding the copyright into the bottom right-hand corner of the figure
% window
DSCopyText = uicontrol('Parent',DSFigure,'Units','characters',...
    'BackgroundColor',get(DSFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 110 1],'String',['Copyright 2009: Eric ',...
    'Young & Andy Kingston '],'Style','text','FontSize',7);

% Generating the plot, segment selection, and segment assignment panels
DSPlotPanel = uipanel('Parent',DSFigure,'Units','characters',...
    'Position',[2 14 106 35]);
DSConPanel = uipanel('Parent',DSFigure,'Units','characters','Position',...
    [2 1 52.5 12]);
DSSelPanel = uipanel('Parent',DSFigure,'Units','characters','Position',...
    [55.5 1 52.5 12]);

% Loading the required icons for the plot manipulation buttons
zoomplus = load([matlabroot,'/toolbox/matlab/icons/zoomplus.mat']);
zoomminus = load([matlabroot,'/toolbox/matlab/icons/zoomminus.mat']);
panbtn = load([matlabroot,'/toolbox/matlab/icons/pan.mat']);
undock = load('undock.mat');

% Generating the plot axes for the reference signal
DSChannelPlotAxes = axes('Parent',DSPlotPanel,'Units',...
    'normalized','OuterPosition',[0 0.5 1 0.5]);

% Creating the plot manipulation buttons for the reference signal plot axes
DSChannelZoomIn = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.84375 0.06 0.07],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
DSChannelZoomOut = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.76375 0.06 0.07],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
DSChannelPan = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',@PanCallback,'CData',panbtn.cdata,...
    'Position',[0.92 0.67375 0.06 0.07],'Style','togglebutton',...
    'TooltipString','Click to Pan along the Plot','Value',0);
DSChannelUnDock = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,DSChannelPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.59375 0.06 0.07],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Generating the plot axes for the selected segment
DSPlotAxes = axes('Parent',DSPlotPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 0.5]);

% Creating the plot manipulation buttons for the segment signal plot axes
DSZoomIn = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.34375 0.06 0.07],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
DSZoomOut = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.26375 0.06 0.07],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
DSPan = uicontrol('Parent',DSPlotPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.92 0.17375 0.06 0.07],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
DSUnDock = uicontrol('Parent',DSPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,DSPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.09375 0.06 0.07],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Locating all the plot manipulation buttons
allToggleBtns = findall(gcf,'Style','togglebutton');

% Manual segment selection section title
DSTitle1Text = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.75 0.9 0.2],'String',...
    'Enter a Segment Time Frame...','Style','text');

% Start time text field label
DSStartText = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.22 0.12],'String','Start Time:','Style','text');

% Start time units label
DSStartS = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.7 0.65 0.05 0.12],'String','s','Style','text');

% Start time text field
DSStartTextField = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',...
    @DSStartTextFieldCallback,'Position',[0.27 0.65 0.43 0.15],...
    'String',num2str(channel_time(1)),'Style','edit');

% End time text field label
DSEndText = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.45 0.22 0.12],'String','End Time:','Style','text');

% End time units label
DSEndS = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.7 0.45 0.05 0.12],'String','s','Style','text');

% End time text field
DSEndTextField = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','BackgroundColor','w','Enable','off','Position',...
    [0.27 0.45 0.43 0.15],'String',num2str(channel_time(1)+(...
    segment_length-1)/sample_rate),'Style','edit');

% Manual segment selection button
DSTextButton = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','Callback',@DSSegPlot,'Position',...
    [0.8 0.55 0.15 0.15],'String','OK');

% Sequential segmentation section title
DSTitle2Text = uicontrol('Parent',DSConPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.2 0.9 0.2],'String',...
    '...or Use Sequential Segmentation','Style','text');

% Start sequential segmentation button
DSSeqButton = uicontrol('Parent',DSConPanel,'Units','normalized',...
    'Callback',@DSSeqButtonCallback,'Position',[0.05 0.06 0.9 0.2],...
    'String','Begin Sequential Segmentation');

% Assigning a variable title
DSAssignVarTitle = uicontrol('Parent',DSSelPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.75 0.9 0.2],'String',...
    'Enter a Label for this Segment','Style','text');

% Variable name text field
DSAssignVarTextField = uicontrol('Parent',DSSelPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',...
    @DSAssignVarTextFieldCallback,'Enable','off','Position',...
    [0.05 0.65 0.9 0.15],'Style','edit');

% Assigning segment to the workspace as the above variable name
DSAssignVarButton = uicontrol('Parent',DSSelPanel,'Units',...
    'normalized','Callback',@DSAssignVarButtonCallback,'Enable','off',...
    'Position',[0.1 0.45 0.8 0.18],'String',...
    'Assign Segment to Workspace');

% Finish title label
DSReturnTitle = uicontrol('Parent',DSSelPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.2 0.9 0.2],'String',...
    'Return to Main Window?','Style','text');

% Finish button to return to the Main Window
DSReturnButton = uicontrol('Parent',DSSelPanel,'Units','normalized',...
    'Callback',@DSReturnButtonCallback,'Position',[0.2 0.06 0.6 0.2],...
    'String','Finish');

% Automatically plot the reference channel in the channel plot axes during
% initialisation of this function
plot(DSChannelPlotAxes,channel_time,evalin('base',reference_channel));
grid(DSChannelPlotAxes)
xlabel(DSChannelPlotAxes,'Time /s');
ylabel(DSChannelPlotAxes,['Voltage /',VoltageScale{VoltageValue}]);
title(DSChannelPlotAxes,['Signal from Channel ',reference_channel]);

% Find all the objects located on this figure window
allObjects = findall(DSFigure);

% Set saving variables for the segment signal and its time scale
segment_signal = [];
segment_time = [];

% Make the figure window visible as the initialisation is now complete
set(DSFigure,'Visible','on')

% Make the program wait until the function has completed its purpose
uiwait(gcf)

    function ZoomIn(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the butotn is toggled
        if get(hObject,'Value')==1
            
            % If the button is toggled, activate the zooming function
            zoom_handle = zoom;
            
            % Set the zooming function to zoom in, and to zoom only in the
            % horizontal direction
            set(zoom_handle,'Direction','in','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function ZoomOut(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check to see if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the zoom function if the button has been toggled on
            zoom_handle = zoom;
            
            % Set the zoom function to zoom out, and to only zoom in the
            % horizontal direction
            set(zoom_handle,'Direction','out','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function UnDock(hObject,eventdata,axes_handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Create a new figure window on which to export the parent plot
        SeparatePlot = figure('ReSize','on');
        
        % Copy all the objects from the parent plot axes to this new figure
        % window
        copyobj(axes_handles,SeparatePlot);
        
        % Resize the plot axes to fill the new figure window
        set(gca,'OuterPosition',[0 0 1 1])
        
    end

    function PanCallback(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Checking if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activating the pan function if the button has been toggled on
            pan_handles = pan;
            
            % Restricting the pan motion to the horizontal axis only
            set(pan_handles,'Enable','on','Motion','horizontal')
            
        else
            
            % Turning off the pan function if the button has been toggled
            % off
            pan off
            
        end
    end

    function DSStartTextFieldCallback(hObject,eventdata,handles)
        
        % Obtaining the string for the start time from the start time text
        % field
        t1 = str2double(get(hObject,'String'));
        
        % Calculating the end time from the start time
        t2 = t1+(segment_length-1)/sample_rate;
        
        % Setting the end time text field to display the end time value
        set(DSEndTextField,'String',num2str(t2))
        
        % Checking that the entered time values fall within the time limits
        % of the signal
        time_error_check = [t1<channel_time(1),t2>(round(channel_time(...
            end)*sample_rate)/sample_rate)];
        
        % Variable name strings for the error checks
        error_search = {'DSStartTextField','DSEndTextField'};
        
        % Checking that valid strings have been entered in the text fields
        if isnan(t1)
            
            % If the start time is not a valid number, display this message
            set(DSStartTextField,'String','NaN')
            
            % Stop the program
            return
            
        elseif sum(time_error_check)>0
            
            % Display this message if either start or end time fall outside
            % of the channel signal's time scale
            set(DSStartTextField,'String','Outside Range')
            
            % Stop the program
            return
            
        else
            
            % If all the checks have been passed, enable the manual segment
            % selector button
            set(DSTextButton,'Enable','on')
            
        end
    end

    function DSSegPlot(hObject,eventdata,handles)
        
        % Obtain the start and end times from the relevant text fields
        t1 = str2double(get(DSStartTextField,'String'));
        t2 = str2double(get(DSEndTextField,'String'));
        
        % Calculate the segment signal's time scale
        segment_time = t1:1/sample_rate:t2;
        
        % Determine the indices in the channel signal which correspond to
        % the selected segment
        segment_indicies = [t1*sample_rate+1, t2*sample_rate+1];
        
        % Extract the segment signal from the channel signal
        segment_signal = evalin('base',sprintf('%s(%d:%d)',...
            reference_channel,segment_indicies(1),segment_indicies(...
            2)));
        
        % Plot the segment signal in the segment plot axes
        plot(DSPlotAxes,segment_time,segment_signal);
        grid(DSPlotAxes)
        xlabel(DSPlotAxes,'Time /s')
        ylabel(DSPlotAxes,['Voltage /',VoltageScale{VoltageValue}])
        title(DSPlotAxes,['Segment Between ',num2str(t1,'%.0f'),...
            's and ',num2str(t2,'%.0f'),'s'])
        
        % Enable the variable name assignment text field
        set(DSAssignVarTextField,'Enable','on')
        
    end

    function DSSeqButtonCallback(hObject,eventdata,handles)
        
        % Set a counter tag for the sequential segmentation program;
        % indicates that the parent originates from this figure window, not
        % the Main Window - does not overwrite global variables
        sequence_counter = 2;
        
        % Disable all objects on this figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Recall the GUI for sequential segmentation
        [segment_signal,segment_time] = GUI_SequentialSegmentation();
        
        % Re-enable all objects on this figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disabling the end time text field
        set(DSEndTextField,'Enable','off')
        
        % Check if a segment has been selected via sequential segmentation
        if ~isempty(segment_signal)||~isempty(segment_time)
            
            % Setting the start and end times to their relevant values
            set(DSStartTextField,'String',num2str(segment_time(1)))
            set(DSEndTextField,'String',num2str(segment_time(end)))
            
            % Plotting the selected segment
            DSSegPlot();
        
        end
    end

    function DSAssignVarTextFieldCallback(hObject,eventdata,handles)
        
        % Obtaining the variable name
        var_str = get(hObject,'String');
        
        % Converting blank spaces to an underscore
        var_str(var_str==' ') = '_';
        
        % Restoring the new string to the text field (no effect if there
        % are no blank spaces)
        set(hObject,'String',var_str)
        
        % Checks if both this text field and the segment signal are not
        % empty
        if ~isempty(var_str) && ~isempty(segment_signal)
            
            % Enables the variable assignment button if it passes the check
            set(DSAssignVarButton,'Enable','on')
            
        end
    end

    function DSAssignVarButtonCallback(hObject,eventdata,handles)
        
        % Checks that the variable name text field is not empty
        if ~isempty(get(DSAssignVarTextField,'String'))
            
            % Obtains the current names of all variables on the base
            % workspace
            base_var = evalin('base','who');
            
            % Checks if the proposed variable name already exists on the
            % base workspace
            if sum(strcmp(base_var,get(DSAssignVarTextField,'String')))>0
                
                % Displays this if a variable with this name already exists
                % on the base workspace
                set(DSAssignVarTextField,'String',...
                    'Variable already Exists')
                
                % Stops the program
                return
                
            else
                
                % Assigns the segment to the base workspace if the variable
                % name is unique
                assignin('base',get(DSAssignVarTextField,'String'),...
                    segment_signal)
                
                % Assigns the segment's time scale to the workspace as the
                % variable name with a suffix '_time'
                assignin('base',[get(DSAssignVarTextField,'String'),...
                    '_time'],segment_time)
                
            end
        end
    end

    function DSReturnButtonCallback(hObject,eventdata,handles)
        
        % Once the 'Finish' button has been selected, resume the program
        % and delete the current figure window
        uiresume(gcf); delete(gcf)
        
    end

end
