function GUI_SingleChannelAnalysis(varargin)
% GUI_SINGLECHANNELANALYSIS is the programmed GUI for single channel 
% analysis that appears in the program 'LFP Analysis Software 2009'.
% 
% GUI_SingleChannelAnalysis(varargin) allows the user to perform Power 
% Spectral Density estimations, generate Spectropograms, Spectrally 
% Decompose a Signal, and calculate the Power Distribution within a single 
% figure window. There are also some Advanced Options available for the 
% first two techniques.
% 
% See also PSD, PERIODOGRAM, PWELCH, PBURG, PCOV, PEIG, PMCOV, PMTM, 
% PMUSIC, PYULEAR, SPECTROGRAM, BAND_DECOMPOSITION, 
% SEGMENT_POWER_DISTRIBUTION, SEGMENT_POWER_DISTRIBUTION_PLOT, 
% SEQUENCE_POWER_DISTRIBUTION, SEQUENCE_POWER_DISTRIBUTION_PLOT,
% NOTCHFILTERHIDDEN, NOTCH_FILTER,GUI_NOTCHFILTER, GUI_CUSTOMBANDS, 
% APPLYWINDOW, ISOLATE_BAND, GUI_WARNING, FOURIER.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading required global variables
global transformed_signal applied_window VoltageScale VoltageValue t1 t2
global sample_rate disabledBtns band_names decibel_range reference_channel
global segment_length frequency applied_filter sequence_counter
global sequence_indices 

% Creating the figure window for SCA
AnaFigure = figure('Units','characters','MenuBar','none','Name',...
    'Single Channel Signal Analysis','NumberTitle','off','Position',...
    [25 3 150 55],'ReSize','off','Visible','off');

% Adding the copyright text to the bottom right-hand corner of the figure
% window
AnaCopyText = uicontrol('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 150 1],'String',['Copyright 2009: Eric ',...
    'Young & Andy Kingston '],'Style','text','FontSize',7);

% Determining the position, width, and height of the figure window
inputPos = get(AnaFigure,'Position');

% Creating the global control menu panel
AnaConPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'Position',[2 47.5 82 6.5],'Title','Control Panel');

% Creating the plot panels for each of the analyses
PSDPlotPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',[2 1 82 46],...
    'Title','Power Spectral Density (PSD)','Visible','off','UserData',...
    'PSDPlot();');
SpecPlotPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',[2 1 82 46],...
    'Title','Spectrogram','Visible','off','UserData','SpecPlot();');
DecompPlotPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',[2 1 82 46],...
    'Title','Spectral Decomposition','Visible','off','UserData',...
    'DecompPlot();');
PowerPlotPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',[2 1 82 46],...
    'Title','Power Distribution','Visible','off','UserData',...
    'PowerPlot();');

% Creating the control panels for each of the analyses
PSDConPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',...
    [84.5 1 63.5 20.25],'Title','Power Spectral Density: Control Panel',...
    'Visible','off');
SpecConPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',...
    [84.5 1 63.5 20.25],'Title','Spectrogram: Control Panel',...
    'Visible','off');
DecompConPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',...
    [84.5 1 63.5 20.25],'Title','Spectral Decomposition: Control Panel',...
    'Visible','off');
PowerConPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'BackgroundColor',get(AnaFigure,'Color'),'Position',...
    [84.5 1 63.5 20.25],'Title','Power Distribution: Control Panel',...
    'Visible','off');

% Global control menu title
AnaConText = uicontrol('Parent',AnaConPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.01 0.08 0.32 0.76],'String',...
    'Select a Type of Analysis to Perform on the Segmented Signal:',...
    'Style','text');

% Global control menu buttons; each one corresponds to one of the four
% types of available analyses
AnaCon1 = uicontrol('Parent',AnaConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.34 0.54 0.32 0.4],...
    'String','Power Spectral Denisty','UserData',{'PSDPlotPanel',...
    'PSDConPanel'},'Visible','on');
AnaCon2 = uicontrol('Parent',AnaConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.34 0.08 0.32 0.4],...
    'String','Spectrogram','UserData',{'SpecPlotPanel','SpecConPanel'},...
    'Visible','on');
AnaCon3 = uicontrol('Parent',AnaConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.67 0.54 0.32 0.4],...
    'String','Spectral Decomposition','UserData',{'DecompPlotPanel',...
    'DecompConPanel'},'Visible','on');
AnaCon4 = uicontrol('Parent',AnaConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.67 0.08 0.32 0.4],...
    'String','Power Distribution','UserData',{'PowerPlotPanel',...
    'PowerConPanel'},'Visible','on');

% Locating all objects currently invisible on the figure window except for
% the figure window itself
dispPanels = findall(gcf,'Visible','off');
dispPanels(dispPanels==AnaFigure) = [];

% Locating all the global control menu buttons
dispButtons = findall(AnaConPanel,'Enable','on');
dispButtons = sort(dispButtons(1:4));

% Creating the original segment signal panel
OrigSigPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'Position',[84.5 21.75 63.5 25.25],'Title',...
    'Signal Pre-Analysis');

% Generating the original segment signal plot axes
OrigSigPlotAxes = axes('Parent',OrigSigPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Loading the icon files for plot manipulation buttons
zoomplus = load([matlabroot,'/toolbox/matlab/icons/zoomplus.mat']);
zoomminus = load([matlabroot,'/toolbox/matlab/icons/zoomminus.mat']);
panbtn = load([matlabroot,'/toolbox/matlab/icons/pan.mat']);
undock = load('undock.mat');

% Creating the plot manipulation buttons for the original segment plot axes
OrigSigZoomIn = uicontrol('Parent',OrigSigPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.915 0.6 0.085 0.09],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
OrigSigZoomOut = uicontrol('Parent',OrigSigPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.915 0.51 0.085 0.09],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
OrigSigPan = uicontrol('Parent',OrigSigPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.915 0.4 0.085 0.09],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
OrigSigUnDock = uicontrol('Parent',OrigSigPanel,'Units',...
    'normalized','Callback',{@UnDock,OrigSigPlotAxes},'CData',...
    undock.cdata,'Position',[0.915 0.31 0.085 0.09],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Setting the PSD information label string
PSDInfoStr = {'Maximum Power Spectral Density:','Frequency @ Max PSD:'};

% Creating a plot axes panel and control panel for PSD
PSDPlotAxesPanel = uipanel('Parent',PSDPlotPanel,'Units','characters',...
    'Position',[1 0.5 79 44]);
PSDConFunPanel = uipanel('Parent',PSDConPanel,'Units','characters',...
    'Position',[1 0.5 60.5 18.25]);

% Generating a plot axes for the PSD plot
PSDPlotAxes = axes('Parent',PSDPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Creating the plot manipulation buttons for the PSD plot
PSDPlotZoomIn = uicontrol('Parent',PSDPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.56 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
PSDPlotZoomOut = uicontrol('Parent',PSDPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.51 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
PSDPlotPan = uicontrol('Parent',PSDPlotAxesPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.92 0.44 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
PSDPlotUnDock = uicontrol('Parent',PSDPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDock,PSDPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.39 0.07 0.05],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% PSD plot type list box strings
PSDTypeName = {'Power Spectrum','Periodogram','Welch','Burg',...
    'Covariance','Eigenvector','Modified Covariance',...
    'Thomson Multitaper','Multiple Signal Classification (MUSIC)',...
    'Yule-Walker'};

% Associated functions for the PSD plot types
PSDTypeFcn = {'PSD(transformed_signal)',...
    'periodogram(transformed_signal,PSD_window,PSD_nfft,PSD_Fs);',...
    ['pwelch(transformed_signal,PSD_window,PSD_overlap,PSD_nfft,',...
    'PSD_Fs);'],'pburg(transformed_signal,PSD_AR,PSD_nfft,PSD_Fs);',...
    'pcov(transformed_signal,PSD_AR,PSD_nfft,PSD_Fs);',...
    'peig(transformed_signal,PSD_p,PSD_nfft,PSD_Fs);',...
    'pmcov(transformed_signal,PSD_AR,PSD_nfft,PSD_Fs);',...
    'pmtm(transformed_signal,PSD_nw,PSD_nfft,PSD_Fs);',...
    'pmusic(transformed_signal,PSD_p,PSD_nfft,PSD_Fs);',...
    'pyulear(transformed_signal,PSD_p,PSD_nfft,PSD_Fs);'};

% PSD frequency axis labels according to PSD plot type
PSDYLabel = {['Power per Sample /',VoltageScale{VoltageValue},'^2'],...
    ['Power per Frequency Bin per Sample /',VoltageScale{VoltageValue},...
    '^2Hz^-^1'],['Power per Frequency Bin per Sample /',...
    VoltageScale{VoltageValue},'^2Hz^-^1'],...
    ['Power per Frequency Bin per Sample /',VoltageScale{VoltageValue},...
    '^2Hz^-^1'],['Power per Frequency Bin per Sample /',...
    VoltageScale{VoltageValue},'^2Hz^-^1'],...
    'Normalised Power/Frequency /dbHz^-^1',...
    ['Power per Frequency Bin per Sample /',VoltageScale{VoltageValue},...
    '^2Hz^-^1'],...
    ['Power per Frequency Bin per Sampley /',VoltageScale{VoltageValue},...
    '^2Hz^-^1'],'Normalised Power/Frequency /dbHz^-^1',...
    ['Power per Frequency Bin per Sample /',VoltageScale{VoltageValue},...
    '^2Hz^-^1']};

% PSD information title
PSDInfoTitle = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'BackgroundColor','w','FontWeight','bold','HorizontalAlignment',...
    'left','Position',[0.05 0.85 0.9 0.09],'String','PSD Information',...
    'Style','text');

% PSD information labels
PSDInfoText = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'BackgroundColor','w','HorizontalAlignment','left','Position',...
    [0.05 0.71 0.6 0.15],'String',PSDInfoStr,'Style','text');

% PSD information values
PSDInfoVar = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'BackgroundColor','w','HorizontalAlignment','left','Position',...
    [0.65 0.71 0.3 0.15],'String',[],'Style','text');

% PSD type title
PSDSelTitle = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.05 0.6 0.9 0.07],'String','Select a Type of PSD Plot','Style',...
    'text');

% PSD type list box
PSDSelList = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'BackgroundColor','w','Callback',@PSDPlot,'Position',...
    [0.05 0.2 0.9 0.4],'String',PSDTypeName,'Style','listbox',...
    'Value',1);

% PSD advanced options button
PSDAdvOpts = uicontrol('Parent',PSDConFunPanel,'Units','normalized',...
    'Callback',@PSDAdvOptsCallback,'Enable','off','Position',...
    [0.3 0.03 0.4 0.15],'String','Advanced Options');

% Spectrogram information label string
SpecInfoStr = {'Maximum Power Spectral Density:','Time @ Max PSD:',...
    'Frequency @ Max PSD:'};

% Creating the spectrogram plot axes and control panels
SpecPlotAxesPanel = uipanel('Parent',SpecPlotPanel,'Units','characters',...
    'Position',[1 0.5 79 44]);
SpecConFunPanel = uipanel('Parent',SpecConPanel,'Units','characters',...
    'Position',[1 0.5 60.5 18.25]);

% Generating the plot axes panel for spectrogram analysis
SpecPlotAxes = axes('Parent',SpecPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Creating plot manipulation buttons for the spectrogram plot
SpecPlotZoomIn = uicontrol('Parent',SpecPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.56 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
SpecPlotZoomOut = uicontrol('Parent',SpecPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.51 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
SpecPlotPan = uicontrol('Parent',SpecPlotAxesPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.92 0.44 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
SpecPlotUnDock = uicontrol('Parent',SpecPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDock,SpecPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.39 0.07 0.05],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Spectrogram information title
SpecInfoTitle = uicontrol('Parent',SpecConFunPanel,'Units','normalized',...
    'BackgroundColor','w','FontWeight','bold','HorizontalAlignment',...
    'left','Position',[0.05 0.87 0.9 0.07],'String',...
    'Spectrogram Information','Style','text');

% Spectrogram information labels
SpecInfoText = uicontrol('Parent',SpecConFunPanel,'Units','normalized',...
    'BackgroundColor','w','HorizontalAlignment','left','Position',...
    [0.05 0.67 0.6 0.2],'String',SpecInfoStr,'Style','text');

% Spectrogram information values
SpecInfoVar = uicontrol('Parent',SpecConFunPanel,'Units','normalized',...
    'BackgroundColor','w','HorizontalAlignment','left','Position',...
    [0.65 0.67 0.3 0.2],'String',[],'Style','text');

% Spectrogram scale title; linear or logarithmic
SpecScale = uibuttongroup('Parent',SpecConFunPanel,'Units','normalized',...
    'BorderType','none','FontWeight','bold','Position',...
    [0.02 0.46 0.96 0.2],'SelectionChangeFcn',@SpecPlot,'Title',...
    'Image Scale');

% Linear scale radio button
SpecLin = uicontrol('Parent',SpecScale,'Units','normalized',...
    'Position',[0.05 0.05 0.45 0.9],'String','Linear Scale','Style',...
    'radiobutton','Value',0);

% Logarithmic scale radio button
SpecLog = uicontrol('Parent',SpecScale,'Units','normalized',...
    'Position',[0.5 0.05 0.45 0.9],'String','Logarithmic Scale',...
    'Style','radiobutton','Value',1);

% Dynamic range check box
SpecdBRChk = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','Callback',@SpecdBRChkCallback,'HorizontalAlignment',...
    'left','Position',[0.05 0.37 0.45 0.08],'String',...
    'Set a Dynamic Range?','Style','checkbox','Value',0);

% Dynamic range text field
SpecdBRText = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',@SpecdBRCallback,...
    'Position',[0.5 0.37 0.4 0.08],'String','60',...
    'Style','edit');

% Dynamic range units
SpecdBRUnits = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.9 0.385 0.05 0.05],'String','dB','Style','text');

% Frequency axis label
SpecdBFreqLimText = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','Callback',@SpecdBRChkCallback,'HorizontalAlignment',...
    'left','Position',[0.05 0.28 0.45 0.067],'String',...
    'Frequency Axis Limits','Style','text');

% Frequency axis text field
SpecdBFreqLim = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',@SpecdBRFreqLim,...
    'Position',[0.5 0.28 0.4 0.08],'String','','Style','edit',...
    'TooltipString','Leave a Space between Limits');

% Frequency axis units
SpecdBRFreqUnits = uicontrol('Parent',SpecConFunPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.9 0.28 0.05 0.067],'String','Hz','Style','text');

% Spectrogram advanced options button
SpecAdvOpts = uicontrol('Parent',SpecConFunPanel,'Units','normalized',...
    'Callback',@SpecAdvOptsCallback,'Position',[0.3 0.03 0.4 0.15],...
    'String','Advanced Options');

% Creating plot axes and control panels for spectral decomposition analysis
DecompPlotAxesPanel = uipanel('Parent',DecompPlotPanel,'Units',...
    'characters','Position',[1 0.5 79 44]);
DecompConFunPanel = uipanel('Parent',DecompConPanel,'Units',...
    'characters','Position',[1 0.5 60.5 18.25]);

% Generating a plot axes for spectral decomposition plots
DecompPlotAxes = axes('Parent',DecompPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Generating the plot manipulation buttons for spectral decomposition
DecompPlotZoomIn = uicontrol('Parent',DecompPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.56 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
DecompPlotZoomOut = uicontrol('Parent',DecompPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.51 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
DecompPlotPan = uicontrol('Parent',DecompPlotAxesPanel,'Units',...
    'normalized','Callback',@PanCallback,'CData',panbtn.cdata,...
    'Position',[0.92 0.44 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click to Pan along the Plot','Value',0);
DecompPlotUnDock = uicontrol('Parent',DecompPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,DecompPlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.92 0.39 0.07 0.05],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Spectral decomposition band selection title
DecompConTitle = uicontrol('Parent',DecompConFunPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.85 0.9 0.09],'String',...
    'Select Band(s) to Display','Style','text');

% Spectral decomposition band selection listbox
DecompConList = uicontrol('Parent',DecompConFunPanel,'Units',...
    'normalized','BackgroundColor','w','Max',length(band_names)+1,'Min',...
    1,'Position',[0.05 0.3 0.9 0.55],'String',band_names,'Style',...
    'listbox','Value',1);

% Spectral decomposition select all bands check box
DecompConSelAll = uicontrol('Parent',DecompConFunPanel,'Units',...
    'normalized','Callback',@DecompSelectAll,'Position',...
    [0.05 0.2 0.9 0.1],'String','Select All','Style','checkbox');

% Plot selected bands from the spectral decomposition list box
DecompConPlotBtn = uicontrol('Parent',DecompConFunPanel,'Units',...
    'normalized','Callback',@DecompPlot,'Position',...
    [0.05 0.03 0.45 0.15],'String','Plot Selected Bands');

% Button to plot all bands of the spectrally decomposed signal on a new
% figure window
DecompConExportBtn = uicontrol('Parent',DecompConFunPanel,'Units',...
    'normalized','Callback',@DecompExport,'Position',...
    [0.5 0.03 0.45 0.15],'String','Export All to a New Figure');

% Creating plot and control panels for power distribution analysis
PowerPlotAxesPanel = uipanel('Parent',PowerPlotPanel,'Units',...
    'characters','Position',[1 0.5 79 44]);
PowerConFunPanel = uipanel('Parent',PowerConPanel,'Units',...
    'characters','Position',[1 0.5 60.5 18.25]);

% Creating a plot axes for the power distribution; two subplots, one for
% the power distribution, and the other for its ratio
PowerPlotAxes = subplot(2,1,1,'Parent',PowerPlotAxesPanel);
PowerRatioPlotAxes = subplot(2,1,2,'Parent',PowerPlotAxesPanel);

% Plot manipulation buttons for both power distribution plots
PowerPlotZoomIn = uicontrol('Parent',PowerPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.56 0.07 0.05],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
PowerPlotZoomOut = uicontrol('Parent',PowerPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.51 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
PowerPlotPan = uicontrol('Parent',PowerPlotAxesPanel,'Units',...
    'normalized','Callback',@PanCallback,'CData',panbtn.cdata,...
    'Position',[0.92 0.44 0.07 0.05],'Style','togglebutton',...
    'TooltipString','Click to Pan along the Plot','Value',0);
PowerPlotUnDock = uicontrol('Parent',PowerPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,PowerPlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.92 0.39 0.07 0.05],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Power distribution selection title
PowerConBtnGroup = uibuttongroup('Parent',PowerConFunPanel,'Units',...
    'normalized','BorderType','none','FontWeight','bold','Position',...
    [0.015 0.77 0.97 0.2],'SelectionChangeFcn',@PowerPlot,'Title',...
    'Power Distribution Plot for...');

% Radio button to plot the power distribution for a single segment
PowerConSingle = uicontrol('Parent',PowerConBtnGroup,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.05 0.45 0.9],'String',' a Single Segment','Style',...
    'radiobutton','Value',1);

% Radio button to plot the power distribution for all segments (requires
% sequential segmentation to have been completed in the Main Window)
PowerConTotal = uicontrol('Parent',PowerConBtnGroup,'Units',...
    'normalized','HorizontalAlignment','left','Enable','off',...
    'Position',[0.5 0.05 0.45 0.9],'String','all Segments','Style',...
    'radiobutton','Value',0);

% Grouping size label
PowerConGroupText = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.69 0.45 0.065],'String','Point Grouping:','Style',...
    'text');

% Grouping size text field
PowerConGroupSize = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',...
    @PowerConGroupSizeCallback,'Position',[0.5 0.69 0.35 0.075],...
    'String','1','Style','edit');

% Grouping size units
PowerConGroupUnits = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','Position',[0.85 0.69 0.1 0.065],'String','points',...
    'Style','text');

% Power distribution band selection title
PowerConTitle = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.55 0.9 0.09],'String',...
    'Select Band(s) to Display','Style','text');

% Power distribution band selection list box
PowerConList = uicontrol('Parent',PowerConFunPanel,'Units','normalized',...
    'BackgroundColor','w','Min',1,'Max',length(band_names)+1,'Position',...
    [0.05 0.2 0.9 0.35],'String',band_names,'Style','listbox','Value',...
    1:length(band_names));

% Power distribution legend toggle button
PowerLegToggle = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','Callback',@ViewPowerLeg,'Position',...
    [0.05 0.03 0.45 0.15],'String','Toggle Legend On/Off');

% Display selected bands from power distribution band selection list box
PowerConPlotBtn = uicontrol('Parent',PowerConFunPanel,'Units',...
    'normalized','Callback',@PowerBandSelection,'Position',...
    [0.5 0.03 0.45 0.15],'String','Display Selected Bands');

% Power distribution legend panel (overlays original segment signal panel
% when toggled on)
PowerLegendPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'Position',[84.5 21.75 63.5 25.25],'Title',...
    'Power Distribution Legend','Visible','off');

% Power distribution legend plot axes (legend is stretched over entire
% axes)
PowerLegendPlotAxes = axes('Parent',PowerLegendPanel,'Units',...
    'normalized','OuterPosition',[0 0 1 1],'XColor','w','XTick',[],...
    'YColor','w','YTick',[]);

% Window names to be displayed in the drop-down list for window functions
Windows_Name = {'None','Modified Bartlett-Hann','Blackman',...
    'Blackman-Harris','Bohman','Chebyshev','Flat Top Weight Window',...
    'Gaussian','Hamming','Hann (Hanning)','Kaiser',...
    'Nuttall-Defined Blackman-Harris','Parzen (de la Valle-Poussin)',...
    'Rectangluar','Tukey','Triangular'};

% Window function names as assigned by the Signal Processing Toolbox
Windows = {'none','barthannwin','bartlett','blackman',...
    'blackmanharris','bohmanwin','chebwin','flattopwin','gausswin',...
    'hamming','hann','kaiser','nuttallwin','parzenwin','rectwin',...
    'tukeywin','triang'};

% Filter panel containing window functions, custom neural bands, and notch
% filters
FilterPanel = uipanel('Parent',AnaFigure,'Units','characters',...
    'Position',[84.5 47.5 63.5 6.5],'Title',...
    'Windowing, Neural Bands, & Notch Filters');

% Window function label
FilterWindowText = uicontrol('Parent',FilterPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.02 0.5 0.3 0.35],'String','Window:','Style','text',...
    'TooltipString','Apply a Window to Signal');

% Window function drop-down list
FilterWindow = uicontrol('Parent',FilterPanel,'Units','normalized',...
    'BackgroundColor','w','Callback',@FilterWindowCallback,'Position',...
    [0.32 0.5 0.66 0.4],'String',Windows_Name,'Style','popupmenu',...
    'Value',1);

% Custom bands button
FilterBand = uicontrol('Parent',FilterPanel,'Units','normalized',...
    'Callback',@FilterBandCallback,'FontWeight','bold','Position',...
    [0.02 0.1 0.47 0.4],'String','Custom Neural Bands?');

% Notch filter button
FilterNotch = uicontrol('Parent',FilterPanel,'Units','normalized',...
    'Callback',@FilterNotchCallback,'FontWeight','bold','Position',...
    [0.51 0.1 0.47 0.4],'String','Apply Notch Filters?');

% Warning mesage for window functions
WarningMsg1 = {['Changing the Window will modify all current Analysis ',...
    'Plots, and remove any previously applied Notch Filters.'],['Do ',...
    'you wish to continue?']};

% Warning message for custom neural bands
WarningMsg2 = {['Customising Neural Bands will modify all current ',...
    'Analysis Plots.'],'Do you wish to continue?'};

% Warning message for notch filters
WarningMsg3 = {['Applying Notch Filters will modify all current ',...
    'Analysis Plots.'],'Do you wish to continue?'};

% Default applied window
applied_window = 'none';

% Finding all objects in the figure window
allObjects = findall(gcf);

% Loading the input variable
inputVar = varargin{1};

% Extracting the segment signal from the input variable
segment_signal = inputVar{1};

% Setting a separate signal variable for spectrogram analysis
spec_signal = segment_signal;

% Setting a separate signal variable for the application of window
% functions and/or notch filters
transformed_signal = segment_signal;

% Determining the time scale of the segment signal
segment_time = t1:1/sample_rate:t2;

% Setting a counter for the number of active analysis techniques
counter = 1;

% Setting a new signal variable as the default signal
prev_signal = segment_signal;

% Setting a new signal variable as the default spectrogram signal
prev_spec_signal = segment_signal;

% Locating all the toggle buttons in the figure window
allToggleBtns = findall(AnaFigure,'Style','togglebutton');

% Setting a default value for the dynamic range
decibel_range = 60;

% Setting the default advanced options values for the PSD plots
PSD_AR=1; PSD_nfft=length(transformed_signal); PSD_nw=1.25; PSD_window=[];
PSD_window_select=1; PSD_overlap=[]; PSD_p=1; PSD_Fs = sample_rate;

% Setting a saving variable for the frequency limits
FreqLim = [];

% Determining the frequency scale of the input signal
frequency = linspace(0,sample_rate/2-1,length(transformed_signal(1:...
    round(length(transformed_signal)/2))));

% Setting initial frequency limits
init_freq = [frequency(1) frequency(end)];

% Setting the frequency limits text field to display these limits
set(SpecdBFreqLim,'String',[num2str(round(frequency(1))),' ',num2str(...
    round(frequency(end)))])

% Default advanced options settings for the spectrogram
Spec_window = Windows{get(FilterWindow,'Value')}; Spec_Adv_Count = 0;
Spec_win_length = floor(segment_length/128); Spec_NO = 1;
Spec_Sample = length(frequency); Spec_Fs = sample_rate; 
Spec_win_select = 1;

% Default grouping size for the single segment power distribution plot
group_size = 1;

% Checking if sequential segmentation has been run in the Main Window
if sequence_counter==1
    
    % Enabling the 'all Segments' radio button if sequential segmentation
    % was run in the Main Window
    set(PowerConTotal,'Enable','on')
    
end

% Setting a saving variable for the power distribution legend
PowerLegend = [];

% Running for all available analysis techniques
for kk = 1:length(dispPanels)
    
    % Obtaining the 'UserData' property from each panel; contains the
    % plotting function for each analysis panel
    plotUData = get(dispPanels(kk),'UserData');
    
    % Checking that the 'UserData' property is not empty
    if ~isempty(plotUData)
        
        % Records the plotting function if the property is not empty
        activePlotUData{counter} = plotUData;
        
        % Evaluates the plotting functin
        eval(plotUData);
        
        % Increases the counter
        counter = counter+1;
        
    end
end

% Plots the original segment signal
SigPlot();

% Extracts the selected option from the input variable
inputSelVar = inputVar{2}-1;

% Checks the value of the selected option
if inputSelVar<=2
    
    % Considers the PSD button selected for the first two options
    set(AnaCon1,'Enable','off')
    
    % Performs the relevant button callback function
    ControlCallback(AnaCon1);
    
else
    
    % Selects the button according to the selected option
    set(dispButtons(inputSelVar-1),'Enable','off')
    
    % Performs the relevant button callback function
    ControlCallback(dispButtons(inputSelVar-1))
    
end

% Makes the figure window visible once initialisation is complete
set(AnaFigure,'Visible','on')

    function ZoomIn(hObject,eventdata,handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the butotn is toggled
        if get(hObject,'Value')==1
            
            % If the button is toggled, activate the zooming function
            zoom_handle = zoom;
            
            % Set the zooming function to zoom in
            set(zoom_handle,'Direction','in','Enable','on')
            
            % Checks if the parent of is the spectrogram plot axes panel
            if get(hObject,'Parent')==SpecPlotAxesPanel
                
                % Sets the motion in both directions for spectrogram
                % analysis
                set(zoom_handle,'Motion','both')
                
            else
                
                % Otherwise restricts motion to the horizontal direction
                set(zoom_handle,'Motion','horizontal')
                
            end
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function ZoomOut(hObject,eventdata,handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check to see if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the zoom function if the button has been toggled on
            zoom_handle = zoom;
            
            % Set the zoom function to zoom out
            set(zoom_handle,'Direction','out','Enable','on')
            
            % Checks if the parent of is the spectrogram plot axes panel
            if get(hObject,'Parent')==SpecPlotAxesPanel
                
                % Sets the motion in both directions for spectrogram
                % analysis
                set(zoom_handle,'Motion','both')
                
            else
                
                % Otherwise restricts motion to the horizontal direction
                set(zoom_handle,'Motion','horizontal')
                
            end
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function UnDock(hObject,eventdata,axes_handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end    
         
        % Create a new figure window on which to export the parent plot
        SeparatePlot = figure('ReSize','on');
        
        % Copy all the objects from the parent plot axes to this new figure
        % window
        copyobj(axes_handles,SeparatePlot);
        
        % Resize the plot axes to fill the new figure window
        set(gca,'OuterPosition',[0 0 1 1])
        
        % Create a colour bar in the figure window if this is the
        % spectrogram plot
        if get(hObject,'Parent')==SpecPlotAxesPanel
            
            % Setting the colour bar to the new figure window
            colorbar('peer',gca,'Location','EastOutside');
            
        end
    end

    function UnDockSub(hObject,eventdata,panel_handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Locating the axes in the parent panel
        axes = findobj(panel_handles,'Type','axes');
        
        % Creating a new figure window
        SeparatePlot = figure('ReSize','on');
        
        % Copying the axes to the new figure window
        copyobj(axes,SeparatePlot);
        
        % Locating all the axes in the new figure window
        SeparatePlotAxes = sort(findobj(SeparatePlot,'Type','axes'));
        
        % Determining the number of axes plots in existence
        num_subplots = length(SeparatePlotAxes);
        
        % Calculating the width of each subplot
        dx = floor(sqrt(num_subplots));
        
        % Calculating the height of each subplot
        dy = ceil(num_subplots/dx);
        
        % Setting the initial position vector (top left)
        x = 0; y = 1-1/dy; 
        
        % Creating a saving position matrix for all subplots and setting 
        % the width and height
        pos = zeros(num_subplots,4); pos(:,3) = 1/dx; pos(:,4) = 1/dy;
        
        % Setting the position for all the subplots
        for ii = 1:num_subplots
            
            % Checking the y-direction
            if y>=0
                
                % Setting the horizontal and vertical positions
                pos(ii,1) = x; pos(ii,2) = y;
                
                % Decreasing the vertical position
                y = y-1/dy;
                
            else
                
                % Resetting the vertical position, and increasing the
                % horizontal position
                y = 1-1/dy; x = x+1/dx;
                
                % Setting the horizontal and vertical positions
                pos(ii,1) = x; pos(ii,2) = y;
                
                % Decreasing the vertical position
                y = y-1/dy;
                
            end
        end
        
        % Setting the position of all the subplots
        for kk = 1:num_subplots
            
            % Setting the 'OuterPosition' property of all the subplots
            set(SeparatePlotAxes(kk),'OuterPosition',squeeze(pos(kk,:)))
            
            % Checking if the parent button is the power distribution axes
            % panel
            if get(hObject,'Parent')==PowerPlotAxesPanel
                
                % Displaying the legend for the power distribution plots
                legend(SeparatePlotAxes(kk),PowerLegend,'Location',...
                    'EastOutside')
                
            end
        end
    end

    function PanCallback(hObject,eventdata,handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Checking if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activating the pan function if the button has been toggled on
            pan_handles = pan;
            
            % Enabling the pan function
            set(pan_handles,'Enable','on')
            
            % Checks if the parent of is the spectrogram plot axes panel
            if get(hObject,'Parent')==SpecPlotAxesPanel
                
                % Sets the motion in both directions for spectrogram
                % analysis
                set(pan_handles,'Motion','both')
                
            else
                
                % Otherwise, restricts motion to the horizontal direction
                set(pan_handles,'Motion','horizontal')
                
            end
        else
            
            % Turn the pan function off if the button is toggled off
            pan off
            
        end
    end

    function ControlCallback(hObject,eventdata,handles)
        
        % Make all the analysis panels invisible and enable all the control
        % menu buttons
        set(dispPanels,'Visible','off'); set(dispButtons,'Enable','on');
        
        % Get the parent button's designated plot and control panel strings
        FunPanel = get(hObject,'UserData');
        
        % Evaluate the strings to obtain the panel variables
        PlotPanel = eval(FunPanel{1}); ConPanel = eval(FunPanel{2});
        
        % Set the plot and control panels to be visible
        set(PlotPanel,'Visible','on'); set(ConPanel,'Visible','on');
        
        % Disable the parent button
        set(hObject,'Enable','off');
        
        % Set the parent button as the disabled object and disable zoom,
        % data cursor, and pan functions
        disabledBtns = hObject; zoom off; datacursormode off; pan off;
        
        % Make the legend invisible
        set(PowerLegendPanel,'Visible','off')
        
        % Make the original segment signal panel visible
        set(OrigSigPanel,'Visible','on')
        
        % Toggle off all the plot manipulation buttons
        for jj = 1:length(allToggleBtns)
            set(allToggleBtns(jj),'Value',0)
        end
        
    end

    function FilterWindowCallback(hObject,eventdata,handles)
        
        % Determining the previously applied window function 
        prev_val = find(strcmp(applied_window,Windows)==1);
        
        % Setting the new window function
        applied_window = Windows{get(hObject,'Value')};
        
        % Setting the window function to be applied to the spectrogram's
        % advanced options
        Spec_window = applied_window;
        
        % Applying the window function to the signal
        transformed_signal = ApplyWindow(segment_signal,applied_window);
        
        % Setting a new default signal
        prev_signal = transformed_signal;
        
        % Disabling the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Displaying the warning message
        WarningValue = GUI_Warning({get(AnaFigure,'Position'),...
            WarningMsg1});
        
        % Enabling the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disabling the current analysis' control button 
        set(disabledBtns,'Enable','off')
        
        % Checking the logical value returned from the warning message
        if WarningValue==1
            
            % Removing the applied filter and the logical governing filter
            % application on the spectrogram signal
            applied_filter = []; Spec_Adv_Count = 0;
            
            % Running through all available analyses
            for jj = 1:length(activePlotUData)
                
                % Updating all the plot analyses
                eval(activePlotUData{jj})
                
            end
            
            % Updating the original segment signal plot
            SigPlot();
            
        else
            
            % Returning the window function drop-down menu to its previous
            % value
            set(FilterWindow,'Value',prev_val)
            
            % Stop the program
            return
            
        end
    end

    function FilterBandCallback(hObject,eventdata,handles)
        
        % Disable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Display the warning message
        WarningValue = GUI_Warning({get(AnaFigure,'Position'),...
            WarningMsg2});
        
        % Enable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disable the current analysis' control menu button
        set(disabledBtns,'Enable','off')
        
        % Check the returned warning logical value
        if WarningValue==1
            
            % Run the customise bands GUI
            GUI_CustomBands(get(AnaFigure,'Position'));
            
            % Change the spectral decomposition and power distribution band
            % selection list boxes
            set(DecompConList,'Max',length(band_names)+1,'String',...
                band_names,'Value',1)
            set(PowerConList,'Max',length(band_names)+1,'String',...
                band_names,'Value',1:length(band_names))
            
            % Running through all available analyses
            for jj = 1:length(activePlotUData)
                
                % Updating all the plot analyses
                eval(activePlotUData{jj})
                
            end
            
            % Updating the original segment signal plot
            SigPlot();
            
        else
            
            % Stop the program
            return
            
        end
        
    end

    function FilterNotchCallback(hObject,eventdata,handles)
        
        % Disable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Display the warning message
        WarningValue = GUI_Warning({get(AnaFigure,'Position'),...
            WarningMsg3});
        
        % Enable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disable the current analysis' control menu button
        set(disabledBtns,'Enable','off')
        
        % Check the warning logical value
        if WarningValue==1
            
            % Apply a notch filter to the signal
            transformed_signal = GUI_NotchFilter({get(AnaFigure,...
                'Position'),transformed_signal,prev_signal});
            
            % Check if a filter exists
            if isempty(applied_filter)
                
                % Restore the spectrogram signal to its default if no
                % filter exists
                spec_signal = prev_spec_signal;     
                
            else
                
                % Apply the filter if it does exist
                spec_signal = NotchFilterHidden(spec_signal);
                
            end
            
            % Running through all available analyses
            for jj = 1:length(activePlotUData)
                
                % Updating all the plot analyses
                eval(activePlotUData{jj})
                
            end
            
            % Updating the original segment signal plot
            SigPlot();
            
        else
            
            % Stop the program
            return
            
        end       
    end

    function SigPlot
        
        % Plot the original segment signal in its axes
        plot(OrigSigPlotAxes,segment_time,transformed_signal)
        grid(OrigSigPlotAxes)
        xlabel(OrigSigPlotAxes,'Time /s')
        ylabel(OrigSigPlotAxes,['Voltage /',VoltageScale{...
            VoltageValue}])
        title(OrigSigPlotAxes,['Segment Between ',num2str(t1,...
            '%.0f'),'s and ',num2str(t2,'%.0f'),'s'])
        
    end

    function PSDPlot(hObject,eventdata,handles)
        
        % Obtain the selected option from the PSD type list box
        PSDType = get(PSDSelList,'Value');
        
        % Checking when to enable the advanced options button
        if PSDType~=1
            
            % Enable the button if 'Power Spectrum' is not selected
            set(PSDAdvOpts,'Enable','on');
            
        else
            
            % Disable the button if 'Power Spectrum' is selected
            set(PSDAdvOpts,'Enable','off');
            
        end
        
        % Obtain the PSD estimate using the selected method
        [psd,frequency] = eval(PSDTypeFcn{PSDType});
        
        % Plot the PSD in the PSD plot axes panel
        plot(PSDPlotAxes,frequency,psd)
        grid(PSDPlotAxes)
        xlabel(PSDPlotAxes,'Frequency /Hz')
        ylabel(PSDPlotAxes,PSDYLabel{PSDType})
        title(PSDPlotAxes,[PSDTypeName{PSDType},' PSD Plot'])
        
        % Set x-axis limits
        xlim(PSDPlotAxes,[0 70])
        
        % Determine the maximum PSD value and the frequency at which this
        % occurs
        PSD_Max = max(max(psd));
        PSD_Max_Freq = max(frequency(psd==PSD_Max));
        
        % Set this to the PSD information section
        set(PSDInfoVar,'String',{num2str(PSD_Max),[num2str(...
            PSD_Max_Freq),'Hz']});
        
    end

    function PSDAdvOptsCallback(hObject,eventdata,handles)
        
        % Disable all currently active objects in the figure window
        activeObjs = findobj(AnaFigure,'Type','uicontrol','-and',...
            'Enable','on');
        set(activeObjs,'Enable','off')
        
        % Create a position matrix for the PSD advanced options
        PSDAOPos = zeros(size(inputPos));
        
        % Set the width and height of the PSD advanced options
        PSDAOPos(3) = 60; PSDAOPos(4) = 25;
        
        % Centre the PSD advanced options figure to the parent callback
        % figure window
        PSDAOPos(1) = ((inputPos(3)-PSDAOPos(3))/2)+inputPos(1);
        PSDAOPos(2) = ((inputPos(4)-PSDAOPos(4))/2)+inputPos(2);
        
        % Get the selected option from the PSD type list box
        PSDType = get(PSDSelList,'Value');
        
        % Generate the figure window
        PSDAdvOptsFigure = figure('Units','characters','MenuBar','none',...
            'Name',['Advanced Options: ',PSDTypeName{PSDType},...
            ' Function'],'NumberTitle','off','Position',PSDAOPos,...
            'ReSize','off','Visible','off');
        
        % Set a panel for the construction of the PSD advanced options
        PSDAdvOptsPanel = uipanel('Parent',PSDAdvOptsFigure,'Units',...
            'normalized','Position',[0.01 0.01 0.98 0.98]);
        
        % General options title
        PSDAOGenTitle = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','FontWeight','bold','HorizontalAlignment',...
            'left','Position',[0.01 0.93 0.98 0.05],'String',...
            'General Options','Style','text');
        
        % General option labels
        PSDAOGenLabels = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.76 0.49 0.15],'String',{'Fourier Transform Length:',...
            '','Sampling Rate:'},'Style','text');
        
        % General option units
        PSDAOGenUnits = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.93 0.76 0.05 0.15],'String',{'','','Hz'},'Style','text');
        
        % Fourier transform length text field
        PSDAONfft = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @AdvBtnDown,'Position',[0.5 0.856 0.43 0.06],'String',...
            num2str(PSD_nfft),'Style','edit');
        
        % Sampling rate text field
        PSDAOFs = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @AdvBtnDown,'Position',[0.5 0.77 0.43 0.06],'String',...
            num2str(PSD_Fs),'Style','edit');
        
        % Specific option title
        PSDAOSpecTitle = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','FontWeight','bold','HorizontalAlignment',...
            'left','Position',[0.01 0.71 0.98 0.05],'String',...
            'Specific Options','Style','text');
        
        % Specific option labels
        PSDAOSpecLabels = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.19 0.49 0.5],'String',{'Type of Window:','',...
            'Number of Overlapping Samples:','',...
            'Order of AutoRegressive (AR) Prediction Model:','',...
            'Signal Subspace Dimension:','','Time-Bandwidth Product:'},...
            'Style','text');
        
        % Applied window drop-down list
        PSDAOWin = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Enable','off',...
            'Position',[0.5 0.635 0.43 0.06],'String',Windows_Name,...
            'Style','popupmenu','Value',PSD_window_select);
        
        % Number of overlapping samples text field
        PSDAOOS = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Enable','off',...
            'Position',[0.5 0.53 0.43 0.06],'String',PSD_overlap,...
            'Style','edit');
        
        % AR model text field
        PSDAOAR = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @AdvBtnDown,'Enable','off','Position',[0.5 0.392 0.43 0.06],...
            'String',num2str(PSD_AR),'Style','edit');
        
        % Signal subspace dimension text field
        PSDAOSSD = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @AdvBtnDown,'Enable','off','Position',[0.5 0.284 0.43 0.06],...
            'String',num2str(PSD_p),'Style','edit');
        
        % Time-bandwith product text field
        PSDAOBP = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @AdvBtnDown,'Enable','off','Position',[0.5 0.193 0.43 0.06],...
            'String',num2str(PSD_nw),'Style','edit');
        
        % Restore defaults check box
        PSDAORD = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','Callback',@PSDAdvOptsRD,'Position',...
            [0.01 0.05 0.49 0.08],'String','Restore Defaults?','Style',...
            'checkbox','Value',0);
        
        % Apply options button
        PSDAOSel = uicontrol('Parent',PSDAdvOptsPanel,'Units',...
            'normalized','Callback',@PSDAdvOptsSel,'Position',...
            [0.5 0.05 0.43 0.08],'String','OK');
        
        % Make the figure window visible once initialisation is complete
        set(PSDAdvOptsFigure,'Visible','on')
        
        % Enabling the correct specific options depending on the selected
        % PSD type
        if sum(PSDType==[2 3])>0
            set(PSDAOWin,'Enable','on'); 
            if PSDType==3
                set(PSDAOOS,'Enable','on');
            end
        elseif sum(PSDType==[4 5 7 11])>0
            set(PSDAOAR,'Enable','on');
        elseif sum(PSDType==[6 9])>0
            set(PSDAOSSD,'Enable','on');
        elseif PSDType==8
            set(PSDAOBP,'Enable','on')
        end
        
        % Locating all the currently enabled user input fields
        user_input = findobj(gcf,'Enable','on','-and','Style','edit',...
            '-or','Enable','on','-and','Style','popupmenu');
        
        % Make the program wait until the options have all been selected
        uiwait(gcf)
        
        % Enable all previously active objects
        set(activeObjs,'Enable','on');
        
        function AdvBtnDown(hObject,eventdata,handles)
            
            % Obtain the string from the parent text field
            text_input = get(hObject,'String');
            
            % Check that, if it is not empty, that it is a numerical value
            if isnan(str2double(text_input))&& ~strcmp(text_input,'[]')
                
                % Display if it is not a numerical value
                set(hObject,'String','Numerical Values Only')
                
            end
        end
        
        function PSDAdvOptsRD(hObject,eventdata,handles)
            
            % Check if the restore default check box has been selected
            if get(hObject,'Value')==1
                
                % Disable all the enabled input fields
                set(user_input,'Enable','off');
                
            else
                
                % Enable all the input fields
                set(user_input,'Enable','on');
                
            end
            
            % Setting the default values            
            set(PSDAONfft,'String',num2str(length(transformed_signal)));
            set(PSDAOFs,'String',num2str(sample_rate));
            set(PSDAOWin,'Value',1); set(PSDAOOS,'String',[]);
            set(PSDAOAR,'String','1'); set(PSDAOSSD,'String','1');
            set(PSDAOBP,'String','1.25');
            
        end
        
        function PSDAdvOptsSel(hObject,eventdata,handles)
            
            % Obtaining the fourier transform length value
            PSD_nfft = str2double(get(PSDAONfft,'String'));
            
            % Obtaining the sample rate value
            PSD_Fs = str2double(get(PSDAOFs,'String'));
            
            % Obtaining the selected window function
            PSD_window_select = get(PSDAOWin,'Value');
            
            % Check if no window function is to be applied
            if strcmp(Windows{PSD_window_select},'none')
                
                % Setting the window function to empty
                PSD_window = [];
                
            else
                
                % Applying the window function to the signal
                PSD_window = eval([Windows{PSD_window_select},...
                    '(length(transformed_signal));']);
                
            end
            
            % Obtaining the number of overlapping samples value
            PSD_overlap = str2double(get(PSDAOOS,'String'));
            
            % Checking if 'PSD_overlap' is not a numerical value
            if isnan(PSD_overlap)
                
                % Setting the overlap to empty if there is no value
                PSD_overlap = [];
                
            end
            
            % Obtaining the order of AR model value
            PSD_AR = str2double(get(PSDAOAR,'String'));
            
            % Obtaining the signal subspace dimension value
            PSD_p = str2double(get(PSDAOSSD,'String'));
            
            % Obtaining the time-bandwidth product value
            PSD_nw = str2double(get(PSDAOBP,'String'));
            
            % Re-plotting the PSD plot, resuming the program, enabling all
            % active objects, and delete the current figure
            PSDPlot(); uiresume(gcbf); set(activeObjs,'Enable','on');
            delete(gcf)
            
        end
        
    end

    function SpecPlot(hObject,eventdata,handles)
        
        % Check if there is any window to be applied
        if isempty(Spec_window)|| strcmp(Spec_window,'none')
            
            % Set only the window length if no window is applied
            Spec_win = Spec_win_length;
            
        else
            
            % Set the window function if there is a window
            Spec_win = eval([Spec_window,'(Spec_win_length);']);
            
        end
        
        % Calculate the spectrogram
        [S F T P] = spectrogram(spec_signal,Spec_win,Spec_NO,...
            Spec_Sample,Spec_Fs,'yaxis');
        
        % Determine the time scale
        T = linspace(t1,t2,length(T));
        
        % Calculate the maximum PSD and the time and frequency at which
        % this occurs
        maxP=max(max(P)); [maxPx maxPy] = find(P==maxP);
        maxT=max(max(T(maxPy))); maxF=max(max(F(maxPy)));
        
        % Update the information variables
        set(SpecInfoVar,'String',{[num2str(10*log10(maxP)),'dB'],...
            [num2str(maxT),'s'],[num2str(maxF),'Hz']})
        
        % Reset the maximum frequency limits
        prev_init_freq = init_freq;
        
        % Change the initial frequency limits
        init_freq = [F(1) F(end)];
        
        % Check if the old and new frequencies are different
        if prev_init_freq~=init_freq
            
            % Set the frequency axis limit text field
            set(SpecdBFreqLim,'String',[num2str(round(init_freq(1))),...
                ' ',num2str(round(init_freq(end)))])
            
            % Set the frequency axis limits
            FreqLim = init_freq;
            
        end
        
        % Determine if a linear or logarithmic scale has been selected
        if get(SpecLin,'Value')==1
            
            % Disable the dynamic range check box and text field
            set(SpecdBRChk,'Enable','off')
            set(SpecdBRText,'Enable','off')
            
            % Generate the spectrogram plot
            image(T,F,abs(P),'Parent',SpecPlotAxes,'CDataMapping','scaled')
            title(SpecPlotAxes,sprintf('Spectrogram (%.0f - %.0fs)',t1,t2))
            
        else
            
            % Enable the dynamic range check box
            set(SpecdBRChk,'Enable','on')
            
            % Check if dynamic range has been selected
            if get(SpecdBRChk,'Value')==1
                
                % Enable the dynamic range text field
                set(SpecdBRText,'Enable','on')
                
                % Calculate the dynamic range
                A = max(max(abs(P))); B = 10^-8*A;
                C = 20*log10(max(abs(P),B)); D = max(max(C));
                dBP = min(D,max(D-decibel_range,C));
                
                % Generate the spectrogram plot
                image(T,F,dBP,'Parent',SpecPlotAxes,'CDataMapping',...
                    'scaled')
                title(SpecPlotAxes,['Spectrogram (',num2str(t1,'%.0f'),...
                    ' - ',num2str(t2,'%.0f'),'s) in ',num2str(...
                    decibel_range,'%.0f'),'dB Range'])
                
            else
                
                % Disable the dynamic range text field
                set(SpecdBRText,'Enable','off')
                
                % Generate the spectrogram plot
                image(T,F,20*log10(abs(P)),'Parent',SpecPlotAxes,...
                    'CDataMapping','scaled')
                title(SpecPlotAxes,['Spectrogram (',num2str(t1,'%.0f'),...
                    ' - ',num2str(t2,'%.0f'),'s) in dB'])
                
            end
        end
        
        % Label the spectrogram plot
        xlabel(SpecPlotAxes,'Time /s')
        ylabel(SpecPlotAxes,'Frequency /Hz')
        set(SpecPlotAxes,'YDir','normal')
        colorbar('peer',SpecPlotAxes,'Location','SouthOutside');
        
        % Set the y-axis limits
        if ~isempty(FreqLim)
            ylim(SpecPlotAxes,FreqLim)
        end
        
    end

    function SpecdBRChkCallback(hObject,eventdata,handles)
        
        % Check the box has been selected
        if get(hObject,'Value')==1
            
            % Enable the dynamic range text field
            set(SpecdBRText,'Enable','on')
            
        else
            
            % Disable the dynamic range text field
            set(SpecdBRText,'Enable','off')
            
        end
        
        % Update the spectrogram plot
        SpecPlot();
        
    end

    function SpecdBRCallback(hObject,eventdata,handles)
        
        % Obtain the dynamic range from the text field 
        decibel_range = str2double(get(hObject,'String'));
        
        % Check if it is a numerical value
        if isnan(decibel_range)
            
            % Display if it is not a numerical value
            set(hObject,'String','NaN');
            
            % Stop the program
            return
            
        else
            
            % Update the spectrogram plot
            SpecPlot();
            
        end
    end

    function SpecdBRFreqLim(hObject,eventdata,handles)
        
        % Form a numerical matrix from the frequency limits
        FreqLim = str2num(get(hObject,'String'));
        
        % Perform checks
        if length(FreqLim)~=2
            
            % Displayed if there aren't two values in the limits
            set(hObject,'String','Must be Two Numbers')
            
            % Stops the program
            return
            
        elseif FreqLim(1)==FreqLim(2)
            
            % Displayed if the limits are identical
            set(hObject,'String','Limits must be Different')
            
            % Stops the program
            return
            
        elseif FreqLim(1)<init_freq(1)||FreqLim(2)>init_freq(end)
            
            % Checks that the limits are within the frequency range
            set(hObject,'String','Outside Range')
            
            % Stops the program
            return
            
        else
            
            % Updates the spectrogram plot
            SpecPlot();
            
        end
    end

    function SpecAdvOptsCallback(hObject,eventdata,handles)
        
        % Locate and disable all currently active objects
        activeObjs = findobj(AnaFigure,'Type','uicontrol','-and',...
            'Enable','on');
        set(activeObjs,'Enable','off')
        
        % Create a position matrix for the advanced options
        SpecAOPos = zeros(size(inputPos));
        
        % Set the width and height of the panel
        SpecAOPos(3) = 60; SpecAOPos(4) = 15;
        
        % Centre the window to the parent figure window
        SpecAOPos(1) = ((inputPos(3)-SpecAOPos(3))/2)+inputPos(1);
        SpecAOPos(2) = ((inputPos(4)-SpecAOPos(4))/2)+inputPos(2);
        
        % Check if a matrix array has been entered for the number of
        % sampling points
        if length(Spec_Sample)>1
            
            % Form a string from the array
            SpecSampleStr = [num2str(Spec_Sample(1)),':',...
                num2str(Spec_Sample(end))];
            
        else
            
            % Form a string from the variable
            SpecSampleStr = num2str(Spec_Sample);
            
        end
        
        % Create a figure window
        SpecAOFigure = figure('Units','characters','MenuBar','none',...
            'Name','Advanced Options: Spectrogram','NumberTitle','off',...
            'Position',SpecAOPos,'ReSize','off','Visible','off');
        
        % Create a panel on which to construct the objects
        SpecAOPanel = uipanel('Parent',SpecAOFigure,'Units',...
            'normalized','Position',[0.01 0.01 0.98 0.98]);
        
        % Advanced options title
        SpecAOTitle = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','FontWeight','bold','HorizontalAlignment',...
            'left','Position',[0.01 0.89 0.98 0.1],'String',...
            'Available Options','Style','text');
        
        % Window function label
        SpecAOWinText = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.78 0.49 0.09],'String','Applied Window:','Style',...
            'text');
        
        % Window function drop-down menu
        SpecAOWin = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','BackgroundColor','w','Position',...
            [0.5 0.8 0.49 0.1],'String',Windows_Name,'Style',...
            'popupmenu');
        
        % Window length label
        SpecAOWinLengthText = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.65 0.49 0.09],'String','Window Length:','Style',...
            'text');
        
        % Window length text field
        SpecAOWinLength = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @SpecAOBtnDown,'Position',[0.5 0.65 0.49 0.1],'String',...
            num2str(Spec_win_length),'Style','edit');
        
        % Number of overlapping segments label
        SpecAONOText = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.47 0.49 0.15],'String',...
            'Number of Overlapping Segments:','Style','text');
        
        % Number of overlapping segments text field
        SpecAONO = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @SpecAOBtnDown,'Position',[0.5 0.5 0.49 0.1],'String',...
            num2str(Spec_NO),'Style','edit');
        
        % Sample points label
        SpecAOSampleText = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.34 0.49 0.09],'String','Number of Sampling Points:',...
            'Style','text');
        
        % Sample points text field
        SpecAOSample = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @SpecAOBtnDown,'Position',[0.5 0.35 0.49 0.1],'String',...
            SpecSampleStr,'Style','edit');
        
        % Sample rate title
        SpecAOFsText = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','HorizontalAlignment','left','Position',...
            [0.01 0.2 0.49 0.09],'String','Sample Rate:','Style','text');
        
        % Sample rate text field
        SpecAOFs = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','BackgroundColor','w','Callback',...
            @SpecAOBtnDown,'Position',[0.5 0.2 0.49 0.1],'String',...
            num2str(Spec_Fs),'Style','edit');
        
        % Restore defaults check box
        SpecAORD = uicontrol('Parent',SpecAOPanel,'Units',...
            'normalized','Callback',@SpecAORDCallback,'Position',...
            [0.01 0.02 0.49 0.15],'String','Restore Defaults?','Style',...
            'checkbox','Value',0);
        
        % Apply options button
        SpecAOBtn = uicontrol('Parent',SpecAOPanel,'Units','normalized',...
            'Callback',@SpecAOBtnCallback,'Position',...
            [0.5 0.02 0.49 0.15],'String','Apply Options');
        
        % Storing the window logical counter
        pre_count = Spec_Adv_Count;
        
        % Checking if a window has been applied to the spectrogram
        if Spec_Adv_Count==0
            
            % Setting the window function drop-down menu to default to this
            set(SpecAOWin,'Value',get(FilterWindow,'Value'))
            
        else
            
            % Setting the window function drop-down menu to be the
            % previously applied window
            set(SpecAOWin,'Value',Spec_Adv_Count)
            
        end
        
        % Making the figure visible once initialisation has been completed
        set(SpecAOFigure,'Visible','on')
        
        % Making the program wait until the function has been completed
        uiwait(gcf)
        
        % Enabling all active objects
        set(activeObjs,'Enable','on')
        
        function SpecAOBtnDown(hObject,eventdata,handles)
            
            % Checking if the parent is the number of overlapping samples
            if hObject~=SpecAOSample
                
                % If not, extract the string
                textField = str2double(get(hObject,'String'));
                
                % Check for numerical values
                if isnan(textField)
                    
                    % Display if not a numerical value
                    set(hObject,'String','NaN');
                    
                    % Disable the apply button
                    set(SpecAOBtn,'Enable','off');
                
                else
                    
                    % Enable the apply button
                    set(SpecAOBtn,'Enable','on');
                    
                end
            else
                
                % Evaluate the string in case it is a matrix
                textField = eval(get(hObject,'String'));
                
                % Check that its a number
                if isnan(textField)
                    
                    % Display if it isn't a numerical value
                    set(hObject,'String','NaN');
                    
                    % Disable the apply button
                    set(SpecAOBtn,'Enable','off');
                    
                else
                    
                    % Enable the apply button
                    set(SpecAOBtn,'Enable','on');
                    
                end
            end
        end
        
        function SpecAORDCallback(hObject,eventdata,handles)
            
            % Check if restore defaults has been selected
            if get(hObject,'Value')==1
                
                % Disable all input fields and set to their default values
                set(SpecAOWin,'Enable','off','Value',...
                    get(FilterWindow,'Value'))
                set(SpecAONO,'Enable','off','String','1')
                set(SpecAOWinLength,'Enable','off','String',...
                    num2str(floor(segment_length/128)))
                set(SpecAOSample,'Enable','off','String',...
                    num2str(length(frequency)))
                set(SpecAOFs,'Enable','off','String',num2str(sample_rate))
                Spec_Adv_Count = 0;
                
            else
                
                % Enable all input fields and set to their previous values
                set(SpecAOWin,'Enable','on')
                set(SpecAONO,'Enable','on')
                set(SpecAOWinLength,'Enable','on')
                set(SpecAOSample,'Enable','on')
                set(SpecAOFs,'Enable','on')
                Spec_Adv_Count = pre_count;
                
            end
        end
        
        function SpecAOBtnCallback(hObject,eventdata,handles)
            
            % Check if restore defaults has been selected
            if get(SpecAOWin,'Value')==1
                
                % Set window function to empty if it is 'None'
                Spec_window = [];
                
            else
                
                % Set the window function to the selected window
                Spec_window = Windows{get(SpecAOWin,'Value')};
                
                % Modify the spectrogram window counter
                Spec_Adv_Count = get(SpecAOWin,'Value');
                
            end
            
            % Obtain the advanced option values
            Spec_win_select = get(SpecAOWin,'Value');
            Spec_win_length = str2double(get(SpecAOWinLength,'String'));
            Spec_NO = str2double(get(SpecAONO,'String'));
            Spec_Sample = eval(get(SpecAOSample,'String'));
            Spec_Fs = str2double(get(SpecAOFs,'String'));
            
            % Update the spectrogram plot, resume the program, and delete
            % the current figure window
            SpecPlot(); uiresume(gcbf); delete(gcf);
            
        end
    end

    function DecompSelectAll(hObject,eventdata,handles)
        
        % Check if this has been selected
        if get(hObject,'Value')==1
            
            % Disable the list box and select all values
            set(DecompConList,'Enable','off','Value',1:length(band_names))
            
        else
            
            % Enable the list box
            set(DecompConList,'Enable','on','Value',1)
            
        end
    end

    function DecompPlot(hObject,eventdata,handles)
        
        % Obtain the selected bands from the list box
        bands_selected = get(DecompConList,'Value');
        
        % Calculate the number of selected bands
        num_selected = length(bands_selected);
        
        % Perform spectral decomposition
        [decomp_bands,band_powers,band_ratios] = Band_Decomposition(...
            transformed_signal);     
        
        % Clear the plot axes
        delete(DecompPlotAxes)
        clear DecompPlotAxes 
        
        % Run through for each selected band
        for jj = 1:num_selected
            
            % Create a new subplot for the band
            DecompPlotAxes(jj)= subplot(num_selected,1,jj,'Parent',...
                DecompPlotAxesPanel);
            
            % Plot the band to a specific subplot
            plot(gca,segment_time,decomp_bands(bands_selected(jj)+1,:))
            grid(gca)
            xlabel(gca,'Time /s')
            ylabel(gca,'Voltage /mV')
            title(gca,sprintf('%s (%.2f%% of Total RMS Power)',...
                band_names{bands_selected(jj)},100*band_ratios(...
                bands_selected(jj))))
            
        end
    end

    function DecompExport(hObject,eventdata,handles)
        
        % Perform spectral decomposition
        [decomp_bands,band_powers,band_ratios] = Band_Decomposition(...
            transformed_signal);
        
        % Plot all the available bands in a separate figure window
        Band_Decomposition_Plot(segment_time,decomp_bands,band_ratios);
        
    end

    function PowerConGroupSizeCallback(hObject,eventdata,handles)
        
        % Obtaining the group size string
        group_size = str2double(get(hObject,'String'));
        
        % Checking the group size string
        if isnan(group_size)
            
            % Display if not a numerical value
            set(hObject,'String','NaN');
            
            % Stops the program
            return
            
        elseif group_size<1
            
            % Display if the value is less than 1
            set(hObject,'String','Group must be >0')
            
            % Stops the program
            return
            
        elseif group_size>=segment_length-1
            
            % Display if the value is larger than the segment length
            set(hObject,'String','Group Too Large')
            
            % Stops the program
            return
            
        else
            
            % Update the power distribution plot
            PowerPlot();
            
        end
    end

    function PowerPlot(hObject,eventdata,handles)
        
        % Check that the group size is a valid number
        if ~isnan(group_size)
            
            % Check if a segment or all segments is being plotted
            if get(PowerConSingle,'Value')==1
                
                % Hide the legend
                set(PowerLegendPanel,'Visible','off')
                
                % Show the original segment signal panel
                set(OrigSigPanel,'Visible','on')
                
                % Enable the grouping text field
                set(PowerConGroupSize,'Enable','on')
                
                % Peform spectral decomposition
                [decomp_bands,segment_band_powers,segment_band_ratios] =...
                    Band_Decomposition(transformed_signal);
                
                % Perform segment power distribution calculations
                [band_powers_time,band_ratios_time,mean_time,mean_power,...
                    mean_power_ratios] = Segment_Power_Distribution(...
                    decomp_bands,group_size,segment_time);
                
                % Clear the legend matrix
                PowerLegend = [];
                
                % Generate the plots
                PowerLegend = Segment_Power_Distribution_Plot(...
                    PowerPlotAxes,PowerRatioPlotAxes,mean_power,...
                    segment_band_ratios,mean_time,mean_power_ratios);
                
            else
                
                % Hide the legend
                set(PowerLegendPanel,'Visible','off')
                
                % Show the original segment signal panel
                set(OrigSigPanel,'Visible','on')
                
                % Disable the grouping text field
                set(PowerConGroupSize,'Enable','off')
                
                % Perform sequence power distribution calculations
                [band_power_sequence,band_ratio_sequence] = ...
                    Sequence_Power_Distribution(evalin('base',...
                    reference_channel),sequence_indices);
                
                % Calculate the average ratios
                av_ratio = mean(100*band_ratio_sequence,2);
                
                % Clear the legend matrix
                PowerLegend = [];
                
                % Generate the plots
                PowerLegend = Sequence_Power_Distribution_Plot(...
                    PowerPlotAxes,PowerRatioPlotAxes,...
                    band_power_sequence,av_ratio,band_ratio_sequence);
                
            end
            
            % Run the band selection function
            PowerBandSelection();
            
        end
    end

    function PowerBandSelection(hObject,eventdata,handles)
        
        % Get the selected bands
        PowerBandSelect = get(PowerConList,'Value');
        
        % Determine all the lines in the power plot
        AllLines = sort(findobj(PowerPlotAxes,'Type','line'));
        
        % Determine all the lines in the ratio plot
        AllRatioLines = sort(findobj(PowerRatioPlotAxes,'Type','line'));
        
        % Set all power and ratio lines to be invisible
        set(AllLines,'Visible','off')
        set(AllRatioLines,'Visible','off')
        
        % Make only the selected bands visible in both plots
        SelectLines = AllLines(PowerBandSelect);
        SelectRatioLines = AllRatioLines(PowerBandSelect);
        set(SelectLines,'Visible','on')
        set(SelectRatioLines,'Visible','on')
        
    end

    function ViewPowerLeg(hObject,eventdata)
        
        % Check if the legend panel is invisible
        if strcmp(get(PowerLegendPanel,'Visible'),'off')
            
            % Make the original segment signal panel invisible
            set(OrigSigPanel,'Visible','off')
            
            % Plot the legend
            plot(PowerLegendPlotAxes,meshgrid(1:length(PowerLegend)),...
                'Visible','off')
            set(PowerLegendPlotAxes,'XColor','w','XTick',[],'YColor',...
                'w','YTick',[])
            legend_handle = legend(PowerLegendPlotAxes,PowerLegend,...
                'Location',get(PowerLegendPlotAxes,'Position'));
            set(legend_handle,'Box','on')
            set(PowerLegendPanel,'Visible','on')
            
        else
            
            % Clear the legend axes
            cla(PowerLegendPlotAxes,'reset')
            
            % Make the legend invisible
            set(PowerLegendPanel,'Visible','off')
            
            % Make the original segment signal panel visible
            set(OrigSigPanel,'Visible','on')
            
        end
    end

end