function varargout = GUI_Warning(varargin)
% GUI_WARNING is the programmed GUI for warning messages that appears in 
% the program 'LFP Analysis Software 2009'.
% 
% varargout = GUI_Warning(varargin) requests the position of the callback
% figure window as the first input variable, and the required warning
% message string as the second input variable. It then displays a new
% figure window in the centre of the callback window which displays the
% message string, and has two options, 'Yes' and 'No', which allow the user
% to either continue with the previously selected option, or to return to
% the callback window without initiating any changes. It returns a logical
% value depending on whether or not 'Yes' (1) or 'No' (0) has been
% selected.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Initialising the selection logical operator
WarningValue = [];

% Loading the input variable
inputVar = varargin{1};

% Separating the input variable to obtain the position of the parent window
inputPos = inputVar{1};

% Initialising a matrix for the position of the warning message
WarningPos = zeros(size(inputPos));

% Setting the width and height of the warning message
WarningPos(3) = 60; WarningPos(4) = 10;

% Calculating the position of the warning message in relation to the parent
% window
WarningPos(1) = ((inputPos(3)-WarningPos(3))/2)+inputPos(1);
WarningPos(2) = ((inputPos(4)-WarningPos(4))/2)+inputPos(2);

% Generating the warning message figure window
WarningFigure = figure('Units','characters','MenuBar','none','Name',...
    'Reset Warning','NumberTitle','off','Position',WarningPos,...
    'ReSize','off','Visible','off');

% Creating the static text box to house the warning message, and loading
% the required message
WarningText = uicontrol('Parent',WarningFigure,'Units','characters',...
    'BackgroundColor',get(WarningFigure,'Color'),'Position',...
    [1 4 58 4],'String',inputVar{2},'Style','text');

% Generating the Yes and No buttons, and setting their respective callbacks
WarningYesButton = uicontrol('Parent',WarningFigure,'Units',...
    'characters','Callback',@YesButton,'Position',[18.5 2 10 2],...
    'String','Yes');
WarningNoButton = uicontrol('Parent',WarningFigure,'Units','characters',...
    'Callback',@NoButton,'Position',[30.5 2 10 2],'String','No');

% Setting the figure to become visible as initialisation has been completed
set(WarningFigure,'Visible','on')

% Cause the program to wait until an option has been selected
uiwait(gcf)

% Setting the output logical value for the decision to be made
mOutputArgs{1} = WarningValue;

% Assigning the output variables
if nargout>0
    [varargout{1:nargout}] = mOutputArgs{:};
end

    function YesButton(hObject,eventdata,handles)
        
        % Setting the logical value if 'Yes' has been selected
        WarningValue = 1;
        
        % Resuming the program, and deleting the warning message
        uiresume(gcbf); delete(gcf);
    end

    function NoButton(hObject,eventdata,handles)
        
        % Setting the logical value if 'No' has been selected
        WarningValue = 0;
        
        % Resuming the program, and deleting the warning message
        uiresume(gcbf); delete(gcf);
    end

end