function notch_filter = Notch_Filter(frequency_scale,lower_limit,...
    upper_limit)
% NOTCH_FILTER generates a Notch Filter at user-defined frequencies.
% 
% notch_filter = Notch_Filter(frequency,lower_limit,upper_limit) computes
% a notch filter at certain bounds, determined by 'lower_limit' and
% 'upper_limit', along the frequency scale denoted by 'frequency_scale'
% using logical arguments.
% 
% See also ISOLATE_BAND.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Using logicals to define the notch filter
lower_bound = abs(frequency_scale)>lower_limit;
upper_bound = abs(frequency_scale)<=upper_limit;

% Creating the notch filter
notch_filter = (lower_bound.*upper_bound)';