function [psd,frequency_scale] = PSD(input_signal)
% PSD determines the power spectral density (PSD) of a given signal.
% 
% [psd,frequency_scale] = PSD(input_signal) computes the PSD of
% 'input_signal', and also returns the corresponding frequency scale,
% 'frequency_scale'.
% 
% See also FFT, BASIC_SIGNAL_ANALYSIS_PLOT.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global sample_rate

% Transform the signal into the frequency domain
transformed_signal = fft(input_signal);

% Extract the required section of the transformed signal
transformed_signal = transformed_signal(1:round(...
    length(transformed_signal)/2));

% Determining the frequency axis
frequency_scale = linspace(0,sample_rate/2-1,length(transformed_signal));

% Calculating the PSD
psd = ((transformed_signal.*conj(transformed_signal))/...
    length(transformed_signal)^2);