function power_dist_legend = Segment_Power_Distribution_Plot(...
    axes_handles_1,axes_handles_2,mean_power,segment_band_ratios,...
    mean_time,mean_power_ratios)
% SEGMENT_POWER_DISTRIBUTION_PLOT plots the power distribution and its
% ratios for a spectrally decomposed signal.
% 
% Segment_Power_Distribution_Plot(axes_handles_1,axes_handles_2,mean_power,
% segment_band_ratios,mean_time,mean_power_ratios) generates two subplots; 
% the first is a plot of mean power against time (variables are 
% 'mean_power' and 'mean_time' respectively) for a user-chosen segment with 
% points grouped according to the user's request and siutated on 
% 'axes_handles_1'. The second is the ratio of this power to that of the
% signal pre-decomposition ('mean_power_ratios'), plotted on 
% 'axes_handles_2'. Both plots are labelled correctly with a legend 
% indiciating the bands and the percentage power for each band using the
% global variables 'band_names', 't1', and 't2'.
% 
% See also SEGMENT_POWER_DISTRIBUTION.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global band_names t1 t2

% Initialising a legend matrix
power_dist_legend = cell(size(mean_power,1),1);

% Create a legend that includes power ratio
for jj = 1:length(power_dist_legend)
    
    % Saving the legend data to a matrix
    power_dist_legend(jj) = {sprintf('%s (Average %.2f%%)',...
        band_names{jj},100*segment_band_ratios(jj))};
    
end

% Plotting the power distribution for a segment
plot(axes_handles_1,mean_time,mean_power,'Visible','off')
grid(axes_handles_1)
xlabel(axes_handles_1,'Time /s')
ylabel(axes_handles_1,'RMS Power /mV^2')
title(axes_handles_1,['RMS Power Distribution Across Frequency Bands (',...
    num2str(t1,'%.0f'),' - ',num2str(t2,'%.0f'),'s)'])
legend(axes_handles_1,'hide',power_dist_legend,'Location','EastOutside')

% Plotting the ratio of power distribution for a segment
plot(axes_handles_2,mean_time,mean_power_ratios,'Visible','off')
grid(axes_handles_2)
xlabel(axes_handles_2,'Time /s')
ylabel(axes_handles_2,'Ratio')
title(axes_handles_2,['RMS Power Distribution Ratios (',num2str(t1,...
    '%.0f'),' - ',num2str(t2,'%.0f'),'s)'])
legend(axes_handles_2,'hide',power_dist_legend,'Location','EastOutside')
