function [band_power_sequence,band_ratio_sequence] = ...
    Sequence_Power_Distribution(input_signal,sequence_indices)
% SEQUENCE_POWER_DISTRIBUTION determines the power distribution of
% 'input_signal' in its seperate bands and returns arrays containing both 
% this and its ratio to the power of 'input_signal'.
% 
% [band_power_sequence,band_ratio_sequence] = Sequence_Power_Distribution
% (input_signal,sequence_indices) computes the power of all the seperate 
% bands, which is obtained from the global variable 'num_bands', and its 
% ratio to the power of 'input signal'. This is done by using a loop to run 
% through all segments, using the global variable 'num_segments', 
% initiating the function 'Band_Decomposition' at each iteration.
% 
% See also BAND_DECOMPOSITION, ISOLATE_BAND.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global num_bands num_segments

% Creating a matrix to save band powers of each segment
band_power_sequence = zeros(num_bands+1,num_segments);

% Calculate the power and ratio distribution across bands
for j = 1:num_segments

    % Selecting which segment from the sequence 
    segment_choice = (sequence_indices(1,j):sequence_indices(2,j));
    
    % Obtaining data for that segment
    segment_signal = input_signal(segment_choice);
       
    % Callback power distribution function for segment
    decomp_bands = Band_Decomposition(segment_signal);
    
    % Saving the data to matricies
    band_power_sequence(:,j) = mean(decomp_bands(2:size(decomp_bands,1),...
        :).^2,2);
    
end

% Reconstruct signal power from bands and create matrix for division;
segment_power_mesh = sum(band_power_sequence,1); 
segment_power_mesh = segment_power_mesh(ones(1,size(band_power_sequence,...
    1)),:);

% Calculate ratio of each band to reconstructed signal
band_ratio_sequence = band_power_sequence./segment_power_mesh;