function power_overview_legend = Sequence_Power_Distribution_Plot(...
    axes_handles_1,axes_handles_2,band_power_sequence,av_ratio,...
    band_ratio_sequence)
% SEQUENCE_POWER_DISTRIBUTION_PLOT forms figures of the power distribution
% and ratio of power distributions for all segments of a given signal.
% 
% Sequence_Power_Distribution_Plot(axes_handles_1,axes_handles_2,
% band_power_sequence,av_ratio,band_ratio_sequence) generates plots of 
% power distribution for decomposed bands of a given signal, obtained from 
% the matrix 'band_power_sequence' on 'axes_handles_1', and their ratio to 
% the power of the signal prior to decomposition, using the matrix 
% 'band_ratio_sequence' on 'axes_handles_2'. The percentage of this power,
% 'av_ratio', is displayed in the legends of each of these plots.
% 
% See also SEQUENCE_POWER_DISTRIBUTION.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global band_names num_segments reference_channel

% Initialise a matrix for the legend
power_overview_legend = cell(size(band_power_sequence,1),1);

% Create a legend that (includes percentage power ratio)
for jj = 1:length(power_overview_legend)
    
    % Legend for the power distributions
    power_overview_legend(jj) = {sprintf('%s (Average %.2f%%)',...
        band_names{jj},av_ratio(jj))};
    
end

% Plot the power distribution
plot(axes_handles_1,1:num_segments,band_power_sequence,'Visible','off')
grid(axes_handles_1)
xlabel(axes_handles_1,'Segment Number')
ylabel(axes_handles_1,'RMS Power /mV^2')
title(axes_handles_1,['Distribution of RMS Power Between Bands (',...
    reference_channel,')'])

% Plot the ratio of the power distribution
plot(axes_handles_2,1:num_segments,band_ratio_sequence,'Visible','off')
grid(axes_handles_2)
xlabel(axes_handles_2,'Segment Number')
ylabel(axes_handles_2,'Ratio to Total Signal')
title(axes_handles_2,['Ratio of RMS Power Distribution (',...
    reference_channel,')'])