function sequence_indicies = Time_Sequence(segment_duration,segment_gap,...
    start_time,num_segments)
% TIME_SEQUENCE Sequential segmentation of a input_signal with user-defined
% variables.
% 
% sequence_indicies = Time_Sequence(segment_duration,segment_gap,
% start_time,num_segments) computes the array indicies, 
% 'sequence_indicies', for all segments of a given input signal. It uses 
% the user-defined input variables 'segment_duration', 'segment_gap', 
% 'start_time', and 'num_segments', the total number of segments, to 
% determine the duration of each segment, the gap between them, and the 
% overall start time before segmentation respectively. 'sample_rate' is 
% supplied as a global variable.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global sample_rate

% Setting end time for the first segment
end_time = start_time+segment_duration;

% Setting up a matrix to save indicies of each segment
sequence_indicies = zeros(2,num_segments);

% Setting up a sequential loop
for j = 1:num_segments
    
    % Saving the data to the time co-ordinates matrix
    sequence_indicies(1,j) = start_time*sample_rate+1;
    sequence_indicies(2,j) = end_time*sample_rate+1;
    
    % Increase the timescale by the interval
    start_time = end_time+segment_gap;
    end_time = start_time+segment_duration;
    
end