function Time_Sequence_Plot(axes_handles,input_signal,sequence_indicies,...
    num_segments)
% TIME_SEQUENCE_PLOT plotting both the original signal and its segments on
% an identical figure.
%
% Time_Sequence_Plot(axes_handles,input_signal,sequence_indicies,
% num_segments) plots the segments in 'axes_handles', with segments 
% indiciated in various colours, on the same figure with correct labels by 
% using the global variables, 'channel_time', 'reference_channel', 
% 'VoltageScale', and 'VoltageValue'.
%
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global channel_time reference_channel VoltageScale VoltageValue

% Determining the segments and displaying them
for kk = 1:num_segments

    % Selecting the appropriate segment
    segment_select = (sequence_indicies(1,kk):sequence_indicies(2,kk));
    
    % Plotting each of the segments
    hold(axes_handles,'all')
    plot(axes_handles,channel_time(segment_select),input_signal(...
        segment_select));
    
end

% Plot parameters
grid(axes_handles)
xlabel(axes_handles,'Time /s')
ylabel(axes_handles,['Voltage /',VoltageScale{VoltageValue}])
title(axes_handles,sprintf('Sequentially Segmented Signal (%s)',...
    reference_channel))