function Welcome(varargin)
% Welcome is the programmed GUI to load a welcome window and perform 
% necessary system checks that appears in the program 'LFP Analysis 
% Software 2009'.
% 
% Welcome(varargin) displays the program's Welcome Logo, and performs
% necessary system checks before allowing the program to run. It checks for
% the Matlab version, as this program should not be run on version older
% than Matlab 7.4.0 (R2007a), and indicates compatibility issues for Matlab
% 7.4.0 (R2007a) or Matlab 7.5.0 (R2007b). It then checks for the existence
% of the Signal Processing Toolbox as this is required to perform any of
% the analysis techniques contained within this program. Once these checks
% have been completed, the Main Window is loaded.
% 
% If you wish to run this file, simply press 'F5' now.
% 
% See also GUI_MAINWINDOW.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%RUN THIS FILE BY PRESSING 'F5' NOW%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Clear all variables, and close all figure windows
clear all
close all

% Add required global variables
global MatlabVersion

% Add the 'GUI Files' folder to the search path
addpath([pwd,'\GUI Files'])

% Create a figure window
WelcomeFigure = figure('Units','characters','MenuBar','none','Name',...
    'LFP Analysis 2009','NumberTitle','off','Position',[50 20.5 100 20],...
    'ReSize','off','Visible','off');

% Create a plot axis for the Welcome Logo
WelcomeImg = axes('Parent',WelcomeFigure,'Units','normalized',...
    'Position',[0 0.2 1 0.8],'XColor','w','XTick',[],...
    'YColor','w','YTick',[]);

% Create a static text field for the Welcome messages/checks
WelcomeCheck = uicontrol('Parent',WelcomeFigure,'Units','normalized',...
    'BackgroundColor',get(WelcomeFigure,'Color'),'HorizontalAlignment',...
    'left','Position',[0.05 0 0.95 0.125],'String','Welcome','Style',...
    'text');

% Load the Welcome Logo file
load WelcomeLogo.mat

% Image the Welcome Logo, constrain the plot axes to the limit, and remove
% all ticks/borders
imagesc(WelcomeLogo);
axis image
set(WelcomeImg,'XTick',[],'YDir','reverse','YTick',[]);

% Make the figure window visible now that initialisation is complete
set(WelcomeFigure,'Visible','on')

% 'Checking Matlab Version' message
pause(2)
set(WelcomeCheck,'String','Checking Matlab Version...')
pause(2)

% Obtain the Matlab release year
MatlabVersion = version('-release');
MatlabVersion = str2double(MatlabVersion(1:4));

% Check for the existence of the Signal Processing Toolbox
SignalToolboxCheck = ver('Signal');

% Check if the Matlab Version is older than Matlab 7.4.0 (R2007a)
if MatlabVersion<2007
    
    % Display this error message
    set(WelcomeCheck,'String',['Matlab 7.4.0 (R2007a) or Higher ',...
        'Required. Press Any Key to Close the Program.'])
    
    % Wait until the user presses any key
    pause
    
    % Delete the Welcome figure and close the program
    delete(WelcomeFigure)
    return
    
else
    
    % Check if the Matlab version is Matlab 7.4.0 (R2007a) or Matlab
    % 7.5.0 (R2007b)
    if MatlabVersion==2007
        
        % Display the compatibility issue messages
        set(WelcomeCheck,'String',['Compatibility Issues Exist with ',...
            'Current Matlab Version.'])
        pause(2)
        set(WelcomeCheck,'String',['Please Refer to the User Guide for',...
            ' More Information. Press Any Key to Continue.'])
        pause
        
    end
    
    % Display the Signal Processing Toolbox check message if it is Matlab
    % 7.6.0 (R2008a) or higher
    set(WelcomeCheck,'String',['Checking for Currently Installed ',...
        'Matlab Toolboxes...'])
    pause(2)
    
    % Check if the Signal Processing Toolbox exists
    if isempty(SignalToolboxCheck)
        
        % Display the error message
        set(WelcomeCheck,'String',['Please Install the Matlab Signal ',...
            'Toolbox. Press Any Key to Close the Program.'])
        
        % Wait for the user to press any key
        pause
        
        % Delete the figure window and close the program
        delete(WelcomeFigure)
        return
        
    else
        
        % Display the loading message if the Signal Processing Toolbox
        % exists
        set(WelcomeCheck,'String','Loading Program, Please Wait...')
        pause(2)
        
        % Loading the Main Window
        run([pwd,'\GUI Files\GUI_MainWindow.m'])
        
        % Delete the figure window
        delete(WelcomeFigure)
        
    end
end